@@ -34,10 +34,12 @@ public:
 
 protected:
     void draw(QPainter *painter);
+    void drawBackground(QPainter *painter);
+    void drawTriggerIndicator(QPainter *painter);
     void initPainter(QPainter *painter);
 
 private:
-    void drawBackground();
+    void prepareBackground();
 };
 
 #endif // ANALOGMETERWIDGET_H
