@@ -43,6 +43,7 @@ MainWindow::MainWindow(QWidget *parent) :
 
     process = NULL;
     meter = 0;
+    triggerCount = 0;
     volumeMeterWidget = NULL;
     changeMeter();
 
@@ -56,6 +57,7 @@ MainWindow::MainWindow(QWidget *parent) :
     sources = new QStringList();
     sources->append("Microphone");
     sources->append("Bluetooth");
+    sources->append("Monitor");
 #else
     sources = (QStringList *) get_source_names();
 #endif
@@ -131,6 +133,12 @@ void MainWindow::getSettings(){
     QSettings settings;
     triggerValue = settings.value(SettingsDialog::TRIGGER_VALUE, 0).toInt();
     triggerCommand = settings.value(SettingsDialog::TRIGGER_COMMAND, "").toString();
+    triggerCountSetting = settings.value(SettingsDialog::TRIGGER_COUNT, 0).toInt();
+
+#ifdef Q_WS_MAEMO_5
+    setAttribute(Qt::WA_Maemo5AutoOrientation,
+                 settings.value(SettingsDialog::AUTO_ROTATE, false).toBool());
+#endif
 
     volumeMeterWidget->setTriggerValue(triggerValue);
 }
@@ -179,6 +187,9 @@ void MainWindow::sourceChanged(int index){
     case 1:
         connect_to_vu_meter_stream("source.hw1", this);
         break;
+    case 2:
+        connect_to_vu_meter_stream("sink.hw0.monitor", this);
+        break;
     default:
         qDebug("Unknown source!");
     }
@@ -201,9 +212,16 @@ void MainWindow::updateValues(float value){
     }
 
     if(vol > triggerValue && process == NULL){
-        process = new QProcess();
-        connect(process, SIGNAL(finished(int)), this, SLOT(processFinished()));
-        process->start(triggerCommand);
+        if(triggerCount >= triggerCountSetting){
+            process = new QProcess();
+            connect(process, SIGNAL(finished(int)), this, SLOT(processFinished()));
+            process->start(triggerCommand);
+            triggerCount = 0;
+        }else{
+            triggerCount++;
+        }
+    }else{
+        triggerCount = 0;
     }
 
     volumeMeterWidget->updateValue(vol);
