@@ -3,8 +3,10 @@
 
 #include <QSettings>
 
+QString SettingsDialog::AUTO_ROTATE = "auto_rotate";
 QString SettingsDialog::TRIGGER = "trigger";
 QString SettingsDialog::TRIGGER_COMMAND = SettingsDialog::TRIGGER + "/command";
+QString SettingsDialog::TRIGGER_COUNT = SettingsDialog::TRIGGER + "/count";
 QString SettingsDialog::TRIGGER_VALUE = SettingsDialog::TRIGGER + "/value";
 
 SettingsDialog::SettingsDialog(QWidget *parent) :
@@ -17,6 +19,14 @@ SettingsDialog::SettingsDialog(QWidget *parent) :
 
     ui->triggerValueEdit->setValue(settings.value(SettingsDialog::TRIGGER_VALUE, 0).toInt());
     ui->triggerCommandEdit->setText(settings.value(SettingsDialog::TRIGGER_COMMAND, "").toString());
+    ui->triggerCountEdit->setValue(settings.value(SettingsDialog::TRIGGER_COUNT, 0).toInt());
+
+#ifdef Q_WS_MAEMO_5
+    ui->autoRotateCheckBox->setChecked(settings.value(SettingsDialog::AUTO_ROTATE, false).toBool());
+#else
+    ui->autoRotateCheckBox->close();
+    ui->autoRotateLabel->close();
+#endif
 }
 
 SettingsDialog::~SettingsDialog()
@@ -29,6 +39,11 @@ void SettingsDialog::accept(){
 
     settings.setValue(SettingsDialog::TRIGGER_VALUE, ui->triggerValueEdit->value());
     settings.setValue(SettingsDialog::TRIGGER_COMMAND, ui->triggerCommandEdit->text());
+    settings.setValue(SettingsDialog::TRIGGER_COUNT, ui->triggerCountEdit->value());
+
+#ifdef Q_WS_MAEMO_5
+    settings.setValue(SettingsDialog::AUTO_ROTATE, ui->autoRotateCheckBox->checkState());
+#endif
 
     settings.sync();
 
