@@ -16,8 +16,10 @@ public:
     explicit SettingsDialog(QWidget *parent = 0);
     ~SettingsDialog();
 
+    static QString AUTO_ROTATE;
     static QString TRIGGER;
     static QString TRIGGER_COMMAND;
+    static QString TRIGGER_COUNT;
     static QString TRIGGER_VALUE;
 
     void accept();
