@@ -27,7 +27,6 @@ VolumeLineChartWidget::VolumeLineChartWidget(QWidget *parent) : VolumeMeterWidge
 
 VolumeLineChartWidget::~VolumeLineChartWidget(){
     delete volumeValues;
-    volumeValues = NULL;
 }
 
 void VolumeLineChartWidget::draw(QPainter *painter){
@@ -42,14 +41,6 @@ void VolumeLineChartWidget::draw(QPainter *painter){
     volumeValues->removeFirst();
     volumeValues->append(vol);
 
-    if(background == NULL){
-        drawBackground();
-    }
-
-    painter->drawImage(QRect(0, 0, w, h),
-                       *background,
-                       QRect(0, 0, w, h));
-
     QPen pen(Qt::darkBlue);
     pen.setWidth(2 * h / 100.);
     painter->setPen(pen);
@@ -62,9 +53,26 @@ void VolumeLineChartWidget::draw(QPainter *painter){
     }
 }
 
-void VolumeLineChartWidget::drawBackground(){
-    initBackground();
+void VolumeLineChartWidget::drawTriggerIndicator(QPainter *painter){
+    float vol;
 
+    if(dbUnit){
+        vol = ((float) triggerValue) / MAX_DB;
+    }else{
+        vol = ((float) triggerValue) / MAX_LINEAR;
+    }
+
+    QPen pen(triggerIndicatorColor);
+    pen.setWidth(2 * h / 100.);
+    painter->setPen(pen);
+
+    painter->drawLine(0.03 * h,
+                      (0.95 * h) - (0.94 * h * vol),
+                      2.71 * h,
+                      (0.95 * h) - (0.94 * h * vol));
+}
+
+void VolumeLineChartWidget::prepareBackground(){
     QPainter painter(background);
     initPainter(&painter);
 
